==> kstars_16.08.3.orig.tar.xz: kstars-16.08.3/Tests/auxiliary/testcsvparser.h <==
/***************************************************************************
                 TestCSVParser.h  -  K Desktop Planetarium
                             -------------------
    begin                : 2012/23/07
    copyright            : (C) 2012 by Rishab Arora
    email                : ra.rishab@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef TESTCSVPARSER_H
#define TESTCSVPARSER_H

#include <QtTest/QtTest>

#include "ksparser.h"
#include "ksfilereader.h"


class TestCSVParser: public QObject {
  Q_OBJECT
 public:
  TestCSVParser();
  ~TestCSVParser();
 private slots:
  void initTestCase();
  void cleanupTestCase();
  void CSVMixedInputs();
  void CSVQuotesInQuotes();
  void CSVEmptyRow();
  void CSVNoRow();
  void CSVIgnoreHasNextRow();
  void CSVReadMissingFile();

 private:
  QStringList test_cases_;
  QList< QPair<QString, KSParser::DataTypes> > sequence_;
  QString test_file_name_;
  KSParser *test_parser_;
};

#endif  // TESTKSPARSER_H

==> kstars-17.07.80.tar.xz: kstars-17.07.80/Tests/auxiliary/testcsvparser.h <==
/***************************************************************************
                 TestCSVParser.h  -  K Desktop Planetarium
                             -------------------
    begin                : 2012/23/07
    copyright            : (C) 2012 by Rishab Arora
    email                : ra.rishab@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TESTCSVPARSER_H
#define TESTCSVPARSER_H

#include <QtTest/QtTest>

#include "ksparser.h"
#include "ksfilereader.h"

class TestCSVParser : public QObject
{
    Q_OBJECT
  public:
    TestCSVParser();
    ~TestCSVParser();
  private slots:
    void initTestCase();
    void cleanupTestCase();
    void CSVMixedInputs();
    void CSVQuotesInQuotes();
    void CSVEmptyRow();
    void CSVNoRow();
    void CSVIgnoreHasNextRow();
    void CSVReadMissingFile();

  private:
    QStringList test_cases_;
    QList<QPair<QString, KSParser::DataTypes>> sequence_;
    QString test_file_name_;
    KSParser *test_parser_;
};

#endif // TESTKSPARSER_H
